@@ -2,21 +2,23 @@ from sys import argv
 
 from htmldump import (
     html_dump,
-    html_to_json,
-    html_tags,
-    html_dump_tags,
+    html_json,
 )
 
 
 html_dump_usage = f'''Usage:
-    html_dump {{path}}
+    html_dump {{path}} {{*args}}
 
     Dumps HTML file
+
+    args:
+         tags  : all tags, no data
+         data  : data only
+        [tags] : tags with data
 '''
 def do_html_dump():
     try:
-        path = argv[1]
-        html_dump(path)
+        html_dump(*argv[1:])
     except Exception as x:
         print(f'\n ! {x} !\n')
         print(html_dump_usage)
@@ -49,18 +51,3 @@ def do_html_tags():
         print(f'\n ! {x} !\n')
         print(html_tags_usage)
 
-
-html_dump_tags_usage = f'''Usage:
-    html_dump_tags {{path}}
-
-    Dumps HTML Tags
-'''
-def do_html_dump_tags():
-    try:
-        path = argv[1]
-        html_dump_tags(path)
-    except Exception as x:
-        print(f'\n ! {x} !\n')
-        print(html_dump_tags_usage)
-
-
